@@ -5,6 +5,14 @@
 
 #include <stdlib.h>
 
+#if defined(__linux__)
+#include <stdint.h>
+#elif defined(__osf__)
+#include <inttypes.h>
+#else
+#include <sys/types.h>
+#endif
+
 #ifndef _MATH_MT_H_
 #define _MATH_MT_H_
 
@@ -12,12 +20,12 @@
 enum { N = 624, M = 397 };
 
 struct mt {
-    unsigned long int mt[N];
+    uint32_t mt[N];
     int mti;
 };
 
-struct mt *mt_setup(unsigned long int seed);
-struct mt *mt_setup_array(unsigned long int *array, int n);
+struct mt *mt_setup(uint32_t seed);
+struct mt *mt_setup_array(uint32_t *array, int n);
 void mt_free(struct mt *self);
 double mt_genrand(struct mt *self);
 
